# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

<!-- insertion marker -->
## [1.0.0](https://github.com/mkdocstrings/griffe-typing-deprecated/releases/tag/1.0.0) - 2024-10-12

<small>[Compare with first commit](https://github.com/mkdocstrings/griffe-typing-deprecated/compare/1dcbba53899c201f0ba1792f6b87978d5fb0d72f...1.0.0)</small>

### Features

- Make project public! ([6c7da38](https://github.com/mkdocstrings/griffe-typing-deprecated/commit/6c7da38581aeca6a93ff205c915afd0942584ab9) by Timothée Mazzucotelli).
